' ========================================================================================
' GdipGetLinePresetBlend
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example sets the colors that are interpolated for this linear gradient
' brush to red, blue, and green and sets the blend positions to 0, 0.3, and 1. The code
' calls the GdipGetLinePresetBlend function to obtain the number of colors currently set
' to be interpolated for the brush. Next, the code gets the colors and their positions.
' Then, the code fills a small rectangle with each color.
' ========================================================================================
SUB GDIP_GetLinePresetBlend (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pLinBrush AS DWORD
   LOCAL colorBlack AS DWORD
   LOCAL colorWhite AS DWORD
   LOCAL colorCount AS LONG
   LOCAL pBrush AS DWORD
   LOCAL i AS LONG
   LOCAL pt1 AS POINTF
   LOCAL pt2 AS POINTF
   DIM   col(2) AS DWORD
   DIM   pos(2) AS SINGLE
   DIM   colors(0) AS DWORD
   DIM   positions(0) AS SINGLE

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Create a linear gradient brush, and set the colors to be interpolated.
   col(0) = GDIP_ARGB(255, 255, 0, 0)
   col(1) = GDIP_ARGB(255, 0, 0, 255)
   col(2) = GDIP_ARGB(255, 0, 255, 0)

   pos(0) = 0.0!   ' // red at the left edge
   pos(1) = 0.3!   ' // blue at 30 percent of the distance from left edge to right edge
   pos(2) = 1.0!   ' // green at the right edge

   pt1.x = 0 : pt1.y = 0 : pt2.x = 100 : pt2.y = 0
   colorBlack = GDIP_ARGB(255, 0, 0, 0)
   colorWhite = GDIP_ARGB(255, 255, 255, 255)

   hStatus = GdipCreateLineBrush(pt1, pt2, colorBlack, colorWhite, %WrapModeTile, pLinBrush)
   hStatus = GdipSetLinePresetBlend(pLinBrush, col(0), pos(0), 3)

   ' // Obtain information about the linear gradient brush.

   ' // How many colors have been specified to be interpolated for this brush?
   hStatus = GdipGetLinePresetBlendCount(pLinBrush, colorCount)
   IF colorCount THEN
      ' // Allocate a buffer large enough to hold the set of colors.
      REDIM colors(colorCount-1)
      ' // Allocate a buffer to hold the relative positions of the colors.
      REDIM positions(colorCount-1)
      ' // Get the colors and their relative positions.
      hStatus = GdipGetLinePresetBlend(pLinBrush, colors(0), positions(0), colorCount)
      FOR i = 0 TO colorCount - 1
         hStatus = GdipCreateSolidFill(colors(i), pBrush)
         IF pBrush THEN
            hStatus = GdipFillRectangle(pGraphics, pBrush, 15 * i, 0, 10, 10)
            hStatus = GdipDeleteBrush(pBrush)
         END IF
      NEXT
   END IF

   ' // Cleanup
   IF pLinBrush THEN GdipDeleteBrush(pLinBrush)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipGetLinePresetBlend", , , 270, 170, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_GetLinePresetBlend hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
